==> ms-users-5.10.0.tgz: package/lib/actions/requestPassword.js <==
'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Promise = require('bluebird');
const getInternalData = require('../utils/getInternalData.js');
const isActive = require('../utils/isActive.js');
const isBanned = require('../utils/isBanned.js');
const hasPassword = require('../utils/hasPassword.js');
const getMetadata = require('../utils/getMetadata.js');
const challenge = require('../utils/challenges/challenge.js');
const {
  USERS_ACTION_PASSWORD,
  USERS_ACTION_RESET,
  USERS_USERNAME_FIELD
} = require('../constants.js');

/**
 * @api {amqp} <prefix>.requestPassword Reset Password
 * @apiVersion 1.0.0
 * @apiName PasswordReset
 * @apiGroup Users
 *
 * @apiDescription Allows one either to request new password instantly, or generate a challenge.
 * In the first case would send new password to email instantly and will change it in the system.
 * Use-case is discouraged, because it can be used to DOS account (throttling not implemented).
 * Second case sends reset token to email and it can be used in `updatePassword` endpoint
 * alongside new password to generate it
 *
 * @apiSchema {jsonschema=../../schemas/requestPassword.json} apiParam
 */
function requestPassword(request) {
  const { challengeType, username: usernameOrAlias, generateNewPassword } = request.params;
  const { [challengeType]: tokenOptions } = this.config.token;
  const { defaultAudience } = this.config.jwt;
  const action = generateNewPassword ? USERS_ACTION_PASSWORD : USERS_ACTION_RESET;

  // TODO: make use of remoteip in security logs?
  // var remoteip = request.params.remoteip;

  return Promise.bind(this, usernameOrAlias).then(getInternalData).tap(isActive).tap(isBanned).tap(hasPassword).then(data => [data[USERS_USERNAME_FIELD], defaultAudience]).spread(getMetadata).get(defaultAudience).then(meta => [challengeType, (0, _extends3.default)({
    id: meta[USERS_USERNAME_FIELD],
    action
  }, tokenOptions), meta]).spread(challenge).return({ success: true });
}

module.exports = requestPassword;

==> ms-users-5.16.0.tgz: package/lib/actions/requestPassword.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const Promise = require('bluebird');
const getInternalData = require('../utils/getInternalData.js');
const isActive = require('../utils/isActive.js');
const isBanned = require('../utils/isBanned.js');
const hasPassword = require('../utils/hasPassword.js');
const getMetadata = require('../utils/getMetadata.js');
const challenge = require('../utils/challenges/challenge.js');
const {
  USERS_ACTION_PASSWORD,
  USERS_ACTION_RESET,
  USERS_USERNAME_FIELD
} = require('../constants.js');

/**
 * @api {amqp} <prefix>.requestPassword Reset Password
 * @apiVersion 1.0.0
 * @apiName PasswordReset
 * @apiGroup Users
 *
 * @apiDescription Allows one either to request new password instantly, or generate a challenge.
 * In the first case would send new password to email instantly and will change it in the system.
 * Use-case is discouraged, because it can be used to DOS account (throttling not implemented).
 * Second case sends reset token to email and it can be used in `updatePassword` endpoint
 * alongside new password to generate it
 *
 * @apiSchema {jsonschema=../../schemas/requestPassword.json} apiParam
 */
function requestPassword(request) {
  const { challengeType, username: usernameOrAlias, generateNewPassword } = request.params;
  const { [challengeType]: tokenOptions } = this.config.token;
  const { defaultAudience } = this.config.jwt;
  const action = generateNewPassword ? USERS_ACTION_PASSWORD : USERS_ACTION_RESET;

  // TODO: make use of remoteip in security logs?
  // var remoteip = request.params.remoteip;

  return Promise.bind(this, usernameOrAlias).then(getInternalData).tap(isActive).tap(isBanned).tap(hasPassword).then(data => [data[USERS_USERNAME_FIELD], defaultAudience]).spread(getMetadata).get(defaultAudience).then(meta => [challengeType, _extends({
    id: meta[USERS_USERNAME_FIELD],
    action
  }, tokenOptions), meta]).spread(challenge).return({ success: true });
}

module.exports = requestPassword;
